@@ -36,12 +36,9 @@ def rings(features_X, features_position, max_radio=[0.00014, 0.00024, 0.00034],
             distances += smoothing
             if(normalize):
                 distances = distances/np.linalg.norm(distances)
-            try:
-                indexs = idxs[nearby_points]
-            except:
-                print("Error nearby points")
+            indexs = idxs[nearby_points]
             for f_index, feature in enumerate(features_X.columns):
-                subset_feature = features_X[feature].values/distances
+                subset_feature = features_X.iloc[indexs, :][feature].values/distances
                 mean_feature = subset_feature.mean()
                 features_array[f_index].append(mean_feature) 
         
